==> qiskit_transpiler_service-0.4.2-py3-none-any.whl: qiskit_transpiler_service/wrappers/ai_routing.py <==
# -*- coding: utf-8 -*-

# (C) Copyright 2024 IBM. All Rights Reserved.
#
# This code is licensed under the Apache License, Version 2.0. You may
# obtain a copy of this license in the LICENSE.txt file in the root directory
# of this source tree or at http://www.apache.org/licenses/LICENSE-2.0.
#
# Any modifications or derivative works of this code must retain this
# copyright notice, and modified files need to carry a notice indicating
# that they have been altered from the originals.

import logging
import os
from urllib.parse import urljoin

from qiskit import QuantumCircuit, qasm2, qasm3
from qiskit.qasm2 import QASM2ExportError

from .base import QiskitTranspilerService

logging.basicConfig()
logger = logging.getLogger(__name__)
logger.setLevel(logging.INFO)


class AIRoutingAPI(QiskitTranspilerService):
    """A helper class that covers some basic funcionality from the AIRouting API"""

    def __init__(self):
        super().__init__("routing")

    def routing(
        self,
        circuit: QuantumCircuit,
        coupling_map,
        optimization_level: int = 1,
        check_result: bool = False,
        layout_mode: str = "OPTIMIZE",
    ):
        is_qasm3 = False
        try:
            qasm = qasm2.dumps(circuit)
        except QASM2ExportError:
            qasm = qasm3.dumps(circuit)
            is_qasm3 = True

        json_args = {"qasm": qasm.replace("\n", " "), "coupling_map": coupling_map}

        params = {
            "check_result": check_result,
            "layout_mode": layout_mode,
            "optimization_level": optimization_level,
        }

        routing_resp = self.request_and_wait(
            endpoint="routing", body=json_args, params=params
        )

        if routing_resp.get("success"):
            routed_circuit = (
                qasm3.loads(routing_resp["qasm"])
                if is_qasm3
                else QuantumCircuit.from_qasm_str(routing_resp["qasm"])
            )
            return (
                routed_circuit,
                routing_resp["layout"]["initial"],
                routing_resp["layout"]["final"],
            )

==> qiskit_transpiler_service-0.4.14-py3-none-any.whl: qiskit_transpiler_service/wrappers/ai_routing.py <==
# -*- coding: utf-8 -*-

# (C) Copyright 2024 IBM. All Rights Reserved.
#
# This code is licensed under the Apache License, Version 2.0. You may
# obtain a copy of this license in the LICENSE.txt file in the root directory
# of this source tree or at http://www.apache.org/licenses/LICENSE-2.0.
#
# Any modifications or derivative works of this code must retain this
# copyright notice, and modified files need to carry a notice indicating
# that they have been altered from the originals.

import os
from urllib.parse import urljoin

from qiskit import QuantumCircuit, qasm2, qasm3
from ..utils import (
    deserialize_circuit_from_qpy_or_qasm,
    get_circuit_from_qpy,
    get_qpy_from_circuit,
    serialize_circuit_to_qpy_or_qasm,
)

from .base import QiskitTranspilerService


class AIRoutingAPI(QiskitTranspilerService):
    """A helper class that covers some basic funcionality from the AIRouting API"""

    def __init__(self, **kwargs):
        super().__init__(path_param="routing", **kwargs)

    def routing(
        self,
        circuit: QuantumCircuit,
        coupling_map,
        optimization_level: int = 1,
        check_result: bool = False,
        layout_mode: str = "OPTIMIZE",
    ):
        qpy, qasm = serialize_circuit_to_qpy_or_qasm(circuit)

        json_args = {"qasm": qasm, "qpy": qpy, "coupling_map": coupling_map}

        params = {
            "check_result": check_result,
            "layout_mode": layout_mode,
            "optimization_level": optimization_level,
        }

        routing_resp = self.request_and_wait(
            endpoint="routing", body=json_args, params=params
        )

        if routing_resp.get("success"):
            routed_circuit = deserialize_circuit_from_qpy_or_qasm(
                routing_resp["qpy"], routing_resp["qasm"]
            )
            return (
                routed_circuit,
                routing_resp["layout"]["initial"],
                routing_resp["layout"]["final"],
            )
